/*********************************************************************
 * Supporting prototypes and definitions for COPAL CJ25 demonstration
 * source file.
 *********************************************************************
 * FileName:        COPAL_main.h
 * Dependencies:    none
 * Processor:       Microchip dsPIC30F3011
 * Compiler:        XC16 v1.24
 *
 * Version: Initial Release v1.0
 * Author: Digi-Key Electronics
 * Date: 23 June 2015
 *
 * SOFTWARE IS PROVIDED "AS IS."  DIGI-KEY EXPRESSLY DISCLAIMS ANY
 * WARRANTY OF ANY KIND, WHETHER EXPRESS OR IMPLIED, INCLUDING BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT. IN NO EVENT SHALL
 * DIGI-KEY BE LIABLE FOR ANY INCIDENTAL, SPECIAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, HARM TO YOUR
 * EQUIPMENT, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY OR
 * SERVICES, ANY CLAIMS BY THIRD PARTIES (INCLUDING BUT NOT LIMITED
 * TO ANY DEFENSE THEREOF), ANY CLAIMS FOR INDEMNITY OR CONTRIBUTION,
 * OR OTHER SIMILAR COSTS. DIGI-KEY ALSO DISCLAIMS ANY LIABILITY FOR
 * PATENT OR COPYRIGHT INFRINGEMENT.
 *
 * Revisions:
 * Date            Comment
 * ------------------------------------------------------------------
 *
 *
 ********************************************************************/

#ifndef MAIN_H
#define	MAIN_H

bool pingpong = true;
bool xValid, yValid = false;

// 7-seg LED digit array map,
// port pins RD1=seg A, RE4=seg B, RE3=seg C, RE1=seg D, RE2=seg E, RE8=seg F, RD0=seg G
// Data in array correspond to numerals that are displayed on the 7-segment LED display
// Position in array represents the digit as well, ie. first data value in array
// is "0", second value is "1", etc. through "9".
__attribute__((space(auto_psv))) int num_array_LATD[]={0x0001,0x0003,0x0000,0x0000,0x0002,0x0000,0x0000,0x0001,0x0000,0x0000};
__attribute__((space(auto_psv))) int num_array_LATE[]={0x0021,0x0127,0x0129,0x0125,0x0027,0x0035,0x0031,0x0127,0x0021,0x0025};

// The array map for the "COPAL" message also incorporates a blank character and 
// repeats the character "C" at the end. This was done to simplify the scroll code.
// Literally, the characters are "COPAL CJ25 C"
__attribute__((space(auto_psv))) int num_array_COPAL_LATD[]={0x0001,0x0001,0x0000,0x0000,0x0003,0x0003,0x0001,0x0003,0x0000,0x0000,0x0003,0x0001};
__attribute__((space(auto_psv))) int num_array_COPAL_LATE[]={0x0039,0x0021,0x002B,0x0022,0x0039,0x013F,0x0039,0x0121,0x0129,0x0035,0x013F,0x0039};

// SCROLL_CHARACTER_CNT must be one less than the "COPAL" message character array size
#define SCROLL_CHARACTER_CNT 11
// SROLL_RATE_CNT of 65 provides ~700mS of character time before moving to the next character.
#define SCROLL_RATE_CNT 65

#define IDLE_MSG_CNT 11880    // ~2 minute
//#define IDLE_MSG_CNT 5940   // ~1 minute
//#define IDLE_MSG_CNT 990    // ~10 seconds

void Initialization(void);
void Selftestdisplay(void);

void __attribute__((interrupt, shadow, auto_psv)) _T1Interrupt(void);

#define OUTPUT 0;
#define INPUT 1;

// Joystick switch port pins
#define jSwitch _RB6  //_LATB6;
#define jSwitchGrnLEDON _LATB7=1;_LATB8=0;   // Green LED half of bi-color LED
#define jSwitchRedLEDON _LATB7=0;_LATB8=1;   // Red LED half of bi-color LED

// Port pin controls the P-channel MOSFET used to multiplex the 7-seg display digits
#define Digit_2_ON _LATE0=1;_LATE5=0;
#define Digit_1_ON _LATE5=1;_LATE0=0;
#define Digits_OFF _LATE5=1;_LATE0=1; //   LATE = 0x0021;LATD = 0x0000;

// high and low value thresholds used in evaluation of the ADC samples 
// from the Joystick.
#define HighValue 818
#define LowValue 205

#define jAllOFF          _LATF0=0;_LATF1=0;_LATF4=0;_LATC13=0;_LATC14=0;
#define ZeroON           _LATF0=0;_LATF1=1;_LATF4=0;_LATC13=0;_LATC14=0;
#define FortyFiveON      _LATF0=1;_LATC13=0;_LATF1=1;_LATF4=1;_LATC14=1;
#define NinetyON         _LATF0=0;_LATC13=1;_LATF1=0;_LATF4=0;_LATC14=0;;
#define OneThirtyFiveON  _LATF0=1;_LATC14=0;_LATF1=1;_LATF4=1;_LATC13=1;
#define OneEightyON      _LATF0=0;_LATC14=1;_LATF1=0;_LATF4=0;_LATC13=0;
#define TwoTwentyFiveON  _LATF0=1;_LATF4=0;_LATF1=1;_LATC13=1;_LATC14=1;
#define TwoSeventyON     _LATF0=0;_LATF4=1;_LATF1=0;_LATC13=0;_LATC14=0;
#define ThreeFifteenON   _LATF0=1;_LATF1=0;_LATF4=1;_LATC13=1;_LATC14=1;
#define AllWhiteON       _LATF0=0;_LATF1=1;_LATF4=1;_LATC13=1;_LATC14=1;
#define AllBlueON         _LATF0=1;_LATC13=0;_LATF1=0;_LATF4=0;_LATC14=0;

#endif	/* MAIN_H */

